
#line 3 "mon_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 205
#define YY_END_OF_BUFFER 206
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[995] =
    {   0,
      101,  195,  101,  195,  101,  101,  101,  101,   86,  101,
       86,  101,  101,  101,  101,  195,  101,  195,  101,  195,
      101,  195,  101,  195,  101,  195,  101,  195,  101,  195,
      101,  104,  101,  104,  100,  101,  100,  101,  206,  204,
      205,  101,  205,  102,  204,  205,   84,  204,  205,  204,
      205,  204,  205,  204,  205,  204,  205,  202,  204,  205,
      204,  205,  195,  197,  200,  204,  205,  192,  195,  197,
      200,  204,  205,  197,  200,  204,  205,  197,  200,  204,
      205,   77,  204,  205,  201,  204,  205,  200,  204,  205,
       93,  200,  204,  205,  200,  204,  205,   91,  200,  204,

      205,   92,  204,  205,  204,  205,  204,  205,   94,  204,
      205,  204,  205,  204,  205,  204,  205,  204,  205,    1,
      204,  205,    3,  204,  205,   34,  204,  205,    4,  204,
      205,   76,  204,  205,    5,   76,  204,  205,   76,  204,
      205,   18,   76,  204,  205,   23,   76,  204,  205,   76,
      204,  205,   32,   76,  204,  205,   33,   76,  204,  205,
       35,   76,  204,  205,   36,   76,  204,  205,   76,  204,
      205,   41,   76,  204,  205,   43,   76,  204,  205,   50,
       76,  204,  205,   52,   76,  204,  205,   76,  204,  205,
       57,   76,  204,  205,   62,   76,  204,  205,   48,   76,

      204,  205,   76,  204,  205,   74,   76,  204,  205,   31,
       76,  204,  205,   76,  204,  205,   68,   76,  204,  205,
        2,  204,  205,   86,  204,  205,   86,  101,  205,   85,
      204,  205,   86,  202,  204,  205,   86,  201,  204,  205,
      105,  204,  205,  105,  202,  204,  205,  105,  201,  204,
      205,  189,  204,  205,  187,  204,  205,  188,  204,  205,
      204,  205,  192,  195,  197,  200,  204,  205,  197,  200,
      204,  205,  190,  204,  205,  200,  204,  205,16562,  179,
      200,  204,  205,  180,  200,  204,  205,  181,  200,  204,
      205,  182,  200,  204,  205,  200,  204,  205,  204,  205,

      183,  204,  205,  204,  205,  184,  204,  205,  185,  204,
      205,  186,  204,  205,  204,  205,  204,  205,  155,  204,
      205,  156,  204,  205,  204,  205,  130,  204,  205,  201,
      204,  205,  131,  204,  205,  204,  205,  106,  200,  204,
      205,  200,  204,  205,  204,  205,  204,  205,  204,  205,
      107,  204,  205,  108,  204,  205,  204,  205,  104,  204,
      205,  104,  204,  205,  104,  204,  205,  104,  204,  205,
      104,  204,  205,  100,  204,  205,  101,  199,  193,  194,
      196,   87,   89,   90,   88,  177,  176,  177,  195,  197,
      200,  197,  200,  200,  192,  195,  197,  200,  192,  195,

      197,  200,   96,   97,   95,   83,   78,  198,   76,   76,
        6,   76,   76,   76,    9,   76,   10,   76,   12,   76,
       13,   76,   14,   76,   76,   16,   76,   76,   76,   76,
       76,   76,   25,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   37,   76,   39,   76,   76,   42,   76,   76,
       22,   76,   44,   76,   76,   76,   76,   49,   76,   76,
       51,   76,   76,   76,   76,   76,   76,   76,   76,   64,
       76,   76,   76,   76,   63,   76,   76,   76,   71,   76,
       72,   76,   76,   76,   86,   86,  101,  105,  192,  195,
      197,  200, 8370,  175,  200,  165,  175,  200,  175,  166,

      175,  200,  167,  175,  200,  168,  175,  169,  175,  172,
      175,  175,  198,  128,  133,  135,  136,  137,  129,  127,
      132,  134,  200,  111,  109,  112,  113,  114,  115,  116,
      117,  118,  110,  203,  104,  104,  104,  100,  177,  176,
      177,  195,  197,  200,  197,  200,  200,  192,  195,  197,
      200,   98,   99,   79,  103,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   20,   76,   24,   76,
       76,   26,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   43,   76,   76,   76,   76,   76,
       76,   76,   53,   76,   76,   55,   76,   56,   76,   76,

       76,   61,   76,   76,   76,   67,   76,   66,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,  175,
      200,  175,  170,  175,  171,  175,  173,  175,  174,  175,
      138,  140,  141,  142,  143,  144,  145,  146,  139,  125,
      119,  120,  121,  122,  123,  124,  126,  195,  197,  200,
      197,  200,  200,  192,  195,  197,  200,   81,   76,   76,
       76,    8,   76,   76,   76,   76,   76,   76,   21,   76,
       76,   76,   19,   76,   76,   76,   76,   76,   76,   29,
       76,   76,   31,   76,   32,   76,   33,   76,   34,   76,
       35,   76,   76,   76,   41,   76,   76,   76,   76,   76,

       46,   76,   76,   48,   76,   50,   76,   76,   76,   54,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   62,
       76,   76,   76,   76,   76,   68,   76,   69,   76,   76,
       76,   76,   76,   76,   76,  175,  200,  175,  153,  147,
      148,  149,  150,  151,  152,  154,  195,  197,  200,  197,
      200,  200,  192,  195,  197,  200,   82,   76,   76,   76,
        9,   76,   76,   11,   76,   12,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   47,   76,   76,   52,   76,
       55,   76,   76,   76,   58,   76,   76,   76,   76,   76,

       76,   76,   65,   76,   76,   76,   76,   71,   76,   76,
       72,   76,   74,   76,   76,  161,  195,  197,  200,  197,
      200,  200,  192,  195,  197,  200,   80,   76,    7,   76,
       76,   76,   76,   76,   76,   76,   76,   24,   76,   27,
       76,   26,   76,   76,   23,   76,   30,   76,   38,   76,
       40,   76,   76,   76,   76,   76,   45,   76,   76,   56,
       76,   76,   59,   76,   76,   60,   76,   61,   76,   76,
       64,   76,   76,   76,   73,   76,   76,  157,  164,  162,
      195,  197,  200,  197,  200,  200,  192,  195,  197,  200,
       76,   76,   76,   76,   76,   17,   76,   18,   76,   76,

       76,   76,   28,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   75,   76,  163,  191,  195,
      197,  200,  191,  197,  200,  191,  200,  191,  192,  195,
      197,  200,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       70,   76,  160,  195,  197,  200,  197,  200,  200,  192,
      195,  197,  200,   76,   76,   76,   19,   76,   76,   76,
       76,   76,   76,   57,   76,   76,   76,   76,   76,   76,
      159,  158,   10,   76,   76,   15,   76,   76,   76,   76,
       76,   76,   76,   76

    } ;

static yyconst flex_int16_t yy_accept[626] =
    {   0,
        1,    3,    5,    6,    7,    8,    9,   11,   13,   14,
       15,   17,   19,   21,   23,   25,   27,   29,   31,   33,
       35,   37,   39,   40,   42,   44,   47,   50,   52,   54,
       56,   58,   61,   63,   68,   74,   78,   82,   85,   88,
       91,   95,   98,  102,  105,  107,  109,  112,  114,  116,
      118,  120,  123,  126,  129,  132,  135,  139,  142,  146,
      150,  153,  157,  161,  165,  169,  172,  176,  180,  184,
      188,  191,  195,  199,  203,  206,  210,  214,  217,  221,
      224,  227,  230,  233,  237,  241,  244,  248,  252,  255,
      258,  261,  263,  269,  273,  276,  280,  284,  288,  292,

      296,  299,  301,  304,  306,  309,  312,  315,  317,  319,
      322,  325,  327,  330,  333,  336,  338,  342,  345,  347,
      349,  351,  354,  357,  359,  362,  365,  368,  371,  374,
      377,  378,  379,  380,  381,  382,  383,  384,  385,  386,
      387,  389,  392,  394,  395,  399,  403,  404,  405,  406,
      407,  407,  407,  408,  408,  408,  409,  409,  410,  411,
      413,  414,  415,  417,  419,  421,  423,  425,  426,  428,
      429,  430,  431,  432,  433,  435,  436,  437,  438,  439,
      440,  441,  442,  443,  445,  447,  448,  450,  451,  453,
      455,  456,  457,  458,  460,  461,  463,  464,  465,  466,

      467,  468,  469,  470,  472,  473,  474,  475,  477,  478,
      479,  481,  483,  484,  485,  486,  488,  489,  493,  493,
      494,  496,  499,  500,  503,  506,  508,  510,  512,  514,
      515,  516,  517,  517,  517,  517,  518,  519,  520,  521,
      522,  523,  524,  525,  526,  526,  527,  528,  529,  530,
      531,  532,  533,  534,  534,  535,  536,  537,  538,  539,
      540,  542,  545,  547,  548,  552,  553,  554,  554,  555,
      555,  555,  556,  557,  558,  559,  560,  561,  562,  563,
      564,  565,  566,  567,  569,  571,  572,  574,  575,  576,
      577,  578,  579,  580,  581,  582,  583,  584,  585,  587,

      588,  589,  590,  591,  592,  593,  595,  596,  598,  600,
      601,  602,  604,  605,  606,  608,  610,  611,  612,  613,
      614,  615,  616,  617,  618,  619,  620,  620,  622,  623,
      625,  627,  629,  631,  631,  632,  632,  633,  634,  635,
      636,  637,  638,  639,  640,  640,  641,  642,  643,  644,
      645,  646,  647,  648,  651,  653,  654,  658,  659,  659,
      659,  660,  661,  662,  664,  665,  666,  667,  668,  669,
      671,  672,  673,  675,  676,  677,  678,  679,  680,  682,
      683,  685,  687,  689,  691,  693,  694,  695,  697,  698,
      699,  700,  701,  703,  704,  706,  708,  709,  710,  712,

      713,  714,  715,  716,  717,  718,  719,  720,  722,  723,
      724,  725,  726,  728,  730,  731,  732,  733,  734,  735,
      736,  736,  736,  736,  738,  739,  740,  741,  742,  743,
      744,  745,  746,  747,  750,  752,  753,  757,  758,  758,
      759,  760,  761,  763,  764,  766,  768,  769,  770,  771,
      772,  773,  774,  775,  776,  777,  778,  779,  780,  781,
      782,  783,  784,  785,  786,  788,  789,  791,  793,  794,
      795,  797,  798,  799,  800,  801,  802,  803,  805,  806,
      807,  808,  810,  811,  813,  815,  816,  816,  817,  817,
      817,  817,  820,  822,  823,  827,  828,  829,  831,  832,

      833,  834,  835,  836,  837,  838,  840,  842,  844,  845,
      847,  849,  851,  853,  854,  855,  856,  857,  859,  860,
      862,  863,  865,  866,  868,  870,  871,  873,  874,  875,
      877,  878,  878,  878,  879,  880,  881,  881,  884,  886,
      887,  891,  892,  893,  894,  895,  896,  898,  900,  901,
      902,  903,  905,  906,  907,  908,  909,  910,  911,  912,
      913,  914,  915,  916,  918,  918,  918,  919,  923,  926,
      928,  933,  934,  935,  936,  937,  938,  939,  940,  941,
      942,  943,  944,  945,  946,  947,  948,  949,  950,  951,
      953,  954,  954,  957,  959,  960,  964,  965,  966,  967,

      969,  970,  971,  972,  973,  974,  976,  977,  978,  979,
      980,  981,  982,  983,  985,  986,  988,  989,  990,  991,
      992,  993,  994,  995,  995
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    7,    8,    9,   10,    1,   11,
       12,    1,   13,   14,    1,   15,    1,   16,   17,   18,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
        1,    1,    1,    1,   33,    1,   34,   35,   36,   37,

       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   55,   56,   57,
       58,   59,    1,   60,    1,   61,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    1,    2,    3,    1,    4,    1,    5,    5,    5,
        6,    1,    5,    7,    1,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    9,    1,    1,    1,    1,
        9,    9,   10,   11,   11,   11,   11,   11,   11,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[660] =
    {   0,
        0,    0,   56,    0,  113,    0,   82,  173,  178,  181,
      210,    0,  267,    0,  322,    0,  249,  336,  394,    0,
      455,  516, 1446, 1447,   66, 1447, 1447,    0,   83,  332,
        0, 1447,  463,  562,   86,  586, 1419, 1447, 1447,    0,
        0, 1418,    0, 1447, 1404, 1394,  139, 1388, 1392, 1382,
        0, 1447, 1447, 1447, 1447,    0,  151,  265,  157,  155,
      142, 1396, 1389,   51,  244, 1398,  277,  330, 1397,  445,
     1380,   29,  515,  240, 1386, 1398,    0, 1373,    0, 1447,
        0,  108, 1447,    0,    0,    0,    0,    0, 1447, 1447,
     1447,  527,   90, 1404, 1447,  624,  682,  590,  685,  688,

      691,    0, 1384,  223,    0, 1371,    0, 1398,  487, 1447,
     1447,  581, 1397, 1396, 1395, 1363, 1386, 1376, 1384,  550,
     1370, 1361, 1360,    0,    0,  273, 1390, 1389, 1388,    0,
      199,    0,  297,  680,    0, 1447, 1447, 1447, 1447,    0,
      358,  715,  725,    0,  307,  462, 1447, 1447, 1447, 1447,
     1379, 1373, 1447, 1363, 1370, 1447, 1403,    0, 1371,    0,
     1354,  290, 1358, 1367, 1370,    0,    0, 1352,    0, 1360,
      318, 1347,  447,  340,    0, 1354, 1365, 1356, 1352, 1343,
     1350, 1347, 1346,    0,    0, 1334,    0, 1357,    0,    0,
     1344,  310, 1334,    0, 1331,    0, 1353, 1344, 1348, 1342,

     1346,  673, 1327, 1330, 1323,  338, 1342,    0,  237, 1329,
     1343,  250, 1323, 1338,    0,  332,    0,  458,  562, 1447,
      751,    0, 1370,    0,    0, 1369,  610,  715, 1368, 1447,
     1447, 1335, 1334,  794, 1320, 1447, 1311, 1447, 1447, 1447,
     1447, 1321, 1447, 1447,  745, 1447, 1447, 1447, 1447, 1447,
     1447, 1447, 1447, 1320,    0,    0, 1339, 1338,    0,    0,
      467,  804,  761,    0,  495, 1447, 1447, 1326, 1447, 1311,
     1321, 1354, 1326, 1324, 1313, 1312,  498, 1321, 1299, 1300,
     1300,  492, 1314, 1309, 1311, 1314, 1305, 1312, 1296, 1309,
     1290, 1297, 1293, 1291, 1286, 1290, 1302, 1299,  670,  521,

     1301, 1296, 1280, 1274, 1284,    0, 1277, 1287, 1280, 1285,
      796, 1272, 1287,  329,    0,    0, 1268, 1285, 1273, 1272,
     1282, 1283, 1264, 1275, 1280, 1277, 1303,  845, 1309, 1308,
     1307, 1306, 1305, 1262, 1447,  834, 1447, 1447, 1447, 1447,
     1447, 1447, 1447, 1447, 1261, 1447, 1447, 1447, 1447, 1447,
     1447, 1447, 1447,  889,  855,    0,  497, 1447, 1268, 1260,
     1259, 1267, 1249,    0, 1264, 1256, 1255, 1260, 1258,    0,
     1262, 1261, 1252, 1251, 1239, 1255, 1254,  498,    0, 1244,
        0,    0,    0,    0,    0, 1237, 1233, 1253, 1244, 1250,
     1234, 1227,    0, 1232,    0,    0, 1245, 1226,    0, 1221,

     1226, 1224, 1222, 1236, 1219, 1234, 1220, 1237, 1231, 1227,
     1234, 1227,    0,    0, 1229, 1226, 1217, 1217, 1220, 1225,
        0, 1245,  899, 1254, 1253, 1447, 1447, 1447, 1447, 1447,
     1447, 1447, 1447,  913,  923,    0,  573, 1447, 1218, 1221,
     1213, 1202,    0, 1219,    0,    0, 1200, 1203, 1198, 1195,
     1195, 1208, 1204, 1206, 1198, 1190, 1203, 1202, 1200, 1193,
     1203, 1187, 1184, 1196,    0, 1199,    0,    0, 1195, 1175,
        0, 1174, 1171, 1168, 1169, 1170, 1162,    0, 1163, 1150,
     1153,    0, 1152,    0,    0, 1146,    0, 1185, 1181, 1180,
        0,  937,  947,    0,  601, 1447, 1154,    0, 1154,   31,

     1146, 1146, 1144, 1139, 1127, 1146,    0,    0, 1140,    0,
        0,    0,    0, 1140, 1122,  653, 1130,    0, 1135,    0,
     1130,    0, 1131,    0,    0, 1129, 1110, 1127, 1109,    0,
     1119, 1146,    0, 1447, 1447, 1447, 1143,  961,  971,    0,
      618, 1116, 1117, 1100, 1082, 1083,    0,    0, 1059, 1049,
     1050,    0, 1055,  796, 1044, 1022, 1030, 1017, 1029, 1031,
     1022, 1027,  815,    0,  845,    0, 1447,  985,  995,    0,
      620,  813,  819,  822,  805,  787,  798,  784,  799,  794,
      776,  764,  710,  720,  705,  253,  691,  680,  682,    0,
        0,  703,    0,    0,    0,  636,  673,  654,  666,    0,

      599,  621,  609,  593,  563,    0,  575,  557,  546,  510,
      516, 1447, 1447,    0,  514,    0,  501,  439,  424,  324,
      320,  259,  163, 1447, 1024, 1036, 1048, 1053,  182, 1060,
     1065, 1076, 1081, 1093, 1105, 1107, 1119, 1124, 1129, 1134,
     1139, 1144, 1153, 1158, 1164, 1174, 1179, 1180, 1186, 1191,
     1192, 1199, 1201, 1206, 1207, 1212, 1213, 1218, 1219
    } ;

static yyconst flex_int16_t yy_def[660] =
    {   0,
      624,    1,    1,    3,  624,    5,  625,  625,  626,  626,
      624,   11,    1,   13,    3,   15,   15,   15,  624,   19,
      627,  627,  624,  624,  624,  624,  624,  628,  624,  624,
      629,  624,  630,  624,   34,  624,   36,  624,  624,  631,
      631,  631,  631,  624,  624,  624,  624,  624,  624,  624,
      632,  624,  624,  624,  624,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  624,
      634,  634,  624,  634,  634,  635,  635,  635,  624,  624,
      624,  630,   34,   36,  624,  624,   96,   96,   96,   96,

       96,  636,  636,  636,  636,  636,  636,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  631,  631,  624,  624,
      624,  624,  624,  637,  638,  638,  638,  638,  638,  639,
      624,  628,  624,  624,  629,  624,  624,  624,  624,  640,
      641,  624,  142,  642,  142,  142,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  632,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,

      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  634,  634,  635,  142,  624,  624,
      624,  221,  643,  221,  221,  643,  643,  643,  643,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  642,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  637,  638,  638,  638,  639,  640,
      641,  624,  262,  644,  262,  624,  624,  624,  624,  624,
      624,  632,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,

      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  645,  624,  646,  646,
      646,  646,  646,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  354,  647,  354,  624,  624,  624,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,

      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      648,  649,  624,  647,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  434,  650,  434,  624,  624,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  651,  652,  624,  624,
      653,  624,  492,  654,  492,  624,  633,  633,  633,  633,

      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  624,  655,  624,  624,  624,  624,  624,  538,  656,
      538,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  624,  657,  624,  624,  568,  658,
      568,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      659,  624,  568,  569,  658,  568,  633,  633,  633,  633,

      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  624,  624,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,    0,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624
    } ;

static yyconst flex_int16_t yy_nxt[1509] =
    {   0,
       24,   25,   26,   25,   24,   27,   24,   28,   29,   30,
       24,   24,   31,   32,   33,   34,   35,   34,   34,   34,
       34,   34,   34,   36,   37,   24,   38,   24,   39,   24,
       24,   24,   24,   40,   41,   42,   43,   40,   40,   24,
       44,   45,   24,   24,   46,   24,   24,   47,   24,   24,
       24,   48,   49,   24,   24,   24,   50,   24,   24,   24,
       24,   51,  201,   24,   24,   24,  202,  131,   24,  131,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,  544,   24,   82,   26,   82,  545,   83,  181,   24,
       24,   24,   24,   24,   24,   84,   24,   24,  133,  133,

       24,  145,  146,   24,  182,  218,  218,   24,   24,  216,
       85,  216,   24,   24,   25,   26,   25,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   32,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   52,
       24,   39,   53,   54,   55,   56,   57,   58,   59,   60,
       61,   62,   63,   64,   65,   56,   66,   67,   68,   69,
       56,   70,   71,   72,   73,   74,   75,   56,   76,   77,
       78,   79,   24,   80,   82,   26,   82,  152,   83,   25,
       26,   25,   25,   26,   25,  153,   84,  159,  177,  135,
      168,   87,  173,  169,   87,  160,  174,  170,  178,  175,

      131,   85,  131,  161,  171,  172,   88,  175,  176,   88,
       24,   25,   26,   25,   24,   24,   89,   28,   29,   30,
       90,   91,   31,   32,   92,   34,   93,   34,   34,   34,
       34,   34,   34,   94,   94,   95,   24,   24,   39,   24,
       24,   24,   24,   96,   97,   98,   99,  100,  101,  102,
      103,  104,  102,  102,  105,  102,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  106,  107,  102,   24,
       24,  108,   24,  210,  319,  124,  109,  110,  111,  227,
      228,  112,   40,  183,  320,  184,  323,   40,  257,  258,
      211,  185,  607,   24,  113,  114,  115,   24,  162,   24,

       24,   40,  324,   40,  608,   50,   24,   24,   24,  163,
      316,   24,  133,  133,   24,  164,  165,  166,   24,   24,
      167,  187,  265,  265,  188,  275,  116,   24,  189,   28,
       29,   30,  266,  216,   31,  216,  276,   34,   93,   34,
       34,   34,   34,   34,   34,   94,   94,  134,  134,  134,
      134,  134,  134,  134,  134,  117,   40,   40,   40,   40,
      118,  300,  124,  282,  283,  190,  409,  191,  301,   40,
      119,  208,  120,  121,   40,  192,  524,  193,  122,  123,
      410,  194,  316,  260,   24,  317,   24,   24,  260,  260,
      189,  288,   50,   24,   24,   25,   26,   25,   24,   24,

       24,   24,   24,   24,   24,   24,   24,   32,   24,  125,
      126,  125,  125,  125,  125,  125,  125,  127,  128,   24,
       24,   24,   39,   24,   24,   24,  125,  125,  125,  129,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,   24,   24,   24,   25,   26,   25,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   32,   24,
      136,  137,  138,  265,  265,  139,  522,  265,  265,  196,
       24,   24,   24,   39,   24,   24,   24,  267,  140,  197,
      187,  285,  260,  140,  140,  198,  231,  260,  260,  286,

      199,  287,  134,  134,  134,  134,  134,  134,  134,  134,
      357,  357,  437,  437,   24,   24,   24,   25,   26,   25,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   32,
       24,  365,  455,  366,  624,  624,  624,  371,  623,  624,
      372,   24,   24,   24,   39,   24,   24,   24,  203,  456,
      204,  167,  140,  205,  392,  206,  207,  140,  140,  208,
      622,  393,  478,  219,  220,  219,  245,  209,  246,  247,
      248,  249,  250,  251,  252,   24,   24,  142,  142,  142,
      142,  142,  142,  142,  142,  143,  143,  220,  495,  495,
      621,  624,  624,  624,  620,  144,  144,  144,  144,  144,

      144,  143,  143,  143,  143,  143,  143,  143,  143,  143,
      143,  147,  619,  327,  232,  624,  541,  541,  393,  144,
      144,  144,  144,  144,  144,  219,  220,  219,  221,  233,
      518,  234,  235,  571,  571,  596,  596,  236,  237,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  220,
      330,  596,  596,  618,  331,  617,  370,  221,  221,  221,
      221,  221,  222,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  134,  134,  134,  134,  134,

      134,  134,  134,  616,  554,  389,  615,  624,  309,  614,
      624,  555,  310,  624,  613,  390,  624,  224,  327,  611,
      221,  391,  225,  221,  311,  312,  221,  610,  609,  221,
      262,  262,  262,  262,  262,  262,  262,  262,  263,  263,
      263,  263,  263,  263,  263,  263,  263,  263,  264,  264,
      264,  264,  264,  264,  327,  332,  606,  194,  465,  333,
      347,  348,  349,  350,  351,  352,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  355,  355,  355,  355,
      355,  355,  355,  355,  328,  328,  328,  328,  328,  328,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,

      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      336,  605,  337,  338,  339,  340,  341,  342,  343,  354,
      354,  354,  354,  354,  354,  354,  354,  355,  355,  581,
      604,  603,  602,  403,  601,  404,  582,  356,  356,  356,
      356,  356,  356,  405,  600,  599,  598,  406,  423,  427,
      428,  429,  430,  431,  432,  597,  166,  160,  591,  590,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      435,  435,  435,  435,  435,  435,  435,  435,  424,  424,
      424,  424,  424,  424,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,

      425,  425,  425,  425,  434,  434,  434,  434,  434,  434,
      434,  434,  435,  435,  490,  490,  490,  490,  490,  490,
      490,  490,  436,  436,  436,  436,  436,  436,  492,  492,
      492,  492,  492,  492,  492,  492,  493,  493,  493,  493,
      493,  493,  493,  493,  493,  493,  494,  494,  494,  494,
      494,  494,  538,  538,  538,  538,  538,  538,  538,  538,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      540,  540,  540,  540,  540,  540,  568,  568,  568,  568,
      568,  568,  568,  568,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  570,  570,  570,  570,  570,  570,

      593,  593,  593,  593,  593,  593,  593,  593,  594,  594,
      594,  594,  594,  594,  594,  594,  594,  594,  595,  595,
      595,  595,  595,  595,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,  130,  130,
      130,  130,  130,  130,  130,  130,  130,  130,  130,  130,
      132,  589,  588,  132,  141,  587,  586,  585,  141,  141,
      141,  141,  144,  196,  584,  144,  157,  583,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  158,  580,
      158,  158,  158,  215,  579,  215,  578,  215,  215,  215,

      215,  215,  215,  215,  215,  217,  577,  217,  217,  217,
      217,  217,  217,  217,  217,  217,  217,  223,  223,  255,
      576,  255,  255,  255,  255,  255,  255,  255,  255,  255,
      255,  256,  575,  256,  256,  256,  259,  574,  259,  259,
      259,  260,  260,  260,  260,  260,  261,  261,  261,  261,
      261,  264,  573,  572,  264,  329,  567,  565,  564,  563,
      562,  561,  560,  329,  329,  356,  559,  558,  356,  422,
      557,  556,  190,  553,  422,  422,  425,  552,  551,  550,
      549,  548,  547,  546,  425,  425,  436,  543,  542,  436,
      487,  487,  489,  536,  535,  533,  489,  489,  494,  531,

      530,  494,  532,  532,  534,  529,  315,  528,  527,  534,
      534,  537,  537,  540,  526,  525,  540,  566,  566,  570,
      524,  523,  570,  592,  592,  595,  522,  521,  595,  612,
      612,  520,  519,  518,  517,  516,  515,  514,  513,  512,
      511,  510,  509,  508,  507,  506,  505,  504,  503,  502,
      501,  500,  499,  498,  497,  496,  491,  491,  488,  486,
      485,  484,  483,  482,  481,  480,  479,  478,  477,  476,
      475,  474,  473,  472,  471,  470,  469,  468,  467,  466,
      465,  464,  463,  462,  461,  460,  459,  458,  457,  454,
      453,  452,  451,  450,  449,  448,  447,  446,  445,  444,

      443,  442,  441,  440,  439,  438,  433,  426,  423,  423,
      423,  423,  423,  421,  420,  419,  418,  417,  416,  415,
      414,  413,  412,  411,  408,  407,  402,  401,  400,  399,
      398,  397,  396,  395,  394,  388,  387,  386,  385,  384,
      383,  382,  381,  380,  379,  378,  377,  376,  375,  374,
      373,  370,  369,  368,  367,  364,  363,  362,  361,  272,
      360,  359,  358,  267,  266,  353,  346,  345,  344,  335,
      334,  327,  327,  327,  326,  325,  322,  321,  318,  315,
      314,  313,  308,  307,  306,  305,  304,  303,  302,  299,
      298,  297,  296,  295,  294,  293,  292,  291,  290,  289,

      284,  281,  280,  279,  278,  277,  274,  273,  272,  271,
      270,  269,  268,  149,  148,  147,  254,  156,  253,  244,
      243,  242,  241,  240,  239,  238,  230,  229,  226,  624,
      214,  213,  212,  200,  195,  186,  180,  179,  156,  155,
      154,  151,  150,  149,  148,  624,   23,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,

      624,  624,  624,  624,  624,  624,  624,  624
    } ;

static yyconst flex_int16_t yy_chk[1509] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,   72,    3,    3,    3,   72,   25,    3,   25,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,  500,    3,    7,    7,    7,  500,    7,   64,    3,
        3,    3,    3,    3,    3,    7,    3,    3,   29,   29,

        3,   35,   35,    3,   64,   93,   93,    3,    3,   82,
        7,   82,    3,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    8,    8,    8,   47,    8,    9,
        9,    9,   10,   10,   10,   47,    8,   57,   61,  629,
       59,    9,   60,   59,   10,   57,   60,   59,   61,   60,

      131,    8,  131,   57,   59,   59,    9,  623,   60,   10,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   13,   13,   74,  209,   17,   13,   13,   13,  104,
      104,   13,   17,   65,  209,   65,  212,   17,  126,  126,
       74,   65,  586,   13,   13,   13,   13,   17,   58,   17,

       17,   13,  212,   13,  586,   17,   17,   13,   13,   58,
      622,   13,  133,  133,   13,   58,   58,   58,   13,   13,
       58,   67,  145,  145,   67,  162,   13,   15,   67,   15,
       15,   15,  145,  216,   15,  216,  162,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   30,   30,   30,
       30,   30,   30,   30,   30,   15,   15,   15,   15,   15,
       15,  192,   18,  171,  171,   68,  314,   68,  192,   18,
       15,  621,   15,   15,   18,   68,  620,   68,   15,   15,
      314,   68,  206,  141,   18,  206,   18,   18,  141,  141,
      174,  174,   18,   18,   19,   19,   19,   19,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       33,   33,   33,  218,  218,   33,  619,  146,  146,   70,
       21,   21,   21,   21,   21,   21,   21,  146,   33,   70,
      618,  173,  261,   33,   33,   70,  109,  261,  261,  173,

       70,  173,  109,  109,  109,  109,  109,  109,  109,  109,
      265,  265,  357,  357,   21,   21,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,  277,  378,  277,   92,   92,   92,  282,  617,   92,
      282,   22,   22,   22,   22,   22,   22,   22,   73,  378,
       73,  615,   92,   73,  300,   73,   73,   92,   92,   73,
      611,  300,  610,  219,  219,  219,  120,   73,  120,  120,
      120,  120,  120,  120,  120,   22,   22,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,  219,  437,  437,
      609,   98,   98,   98,  608,   34,   34,   34,   34,   34,

       34,   36,   36,   36,   36,   36,   36,   36,   36,   36,
       36,   36,  607,  227,  112,   98,  495,  495,  605,   36,
       36,   36,   36,   36,   36,   96,   96,   96,   98,  112,
      604,  112,  112,  541,  541,  571,  571,  112,  112,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
      227,  596,  596,  603,  227,  602,  601,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   97,   97,   97,   99,   99,   99,  100,
      100,  100,  101,  101,  101,  134,  134,  134,  134,  134,

      134,  134,  134,  599,  516,  299,  598,   97,  202,  597,
       99,  516,  202,  100,  592,  299,  101,   97,  228,  589,
       97,  299,   99,   99,  202,  202,  100,  588,  587,  101,
      142,  142,  142,  142,  142,  142,  142,  142,  142,  142,
      143,  143,  143,  143,  143,  143,  143,  143,  142,  142,
      142,  142,  142,  142,  221,  228,  585,  584,  583,  228,
      245,  245,  245,  245,  245,  245,  221,  221,  221,  221,
      221,  221,  221,  221,  221,  221,  263,  263,  263,  263,
      263,  263,  263,  263,  221,  221,  221,  221,  221,  221,
      221,  221,  221,  221,  221,  221,  221,  221,  221,  221,

      221,  221,  221,  221,  221,  221,  221,  221,  221,  221,
      234,  582,  234,  234,  234,  234,  234,  234,  234,  262,
      262,  262,  262,  262,  262,  262,  262,  262,  262,  554,
      581,  580,  579,  311,  578,  311,  554,  262,  262,  262,
      262,  262,  262,  311,  577,  576,  575,  311,  328,  336,
      336,  336,  336,  336,  336,  574,  573,  572,  565,  563,
      328,  328,  328,  328,  328,  328,  328,  328,  328,  328,
      355,  355,  355,  355,  355,  355,  355,  355,  328,  328,
      328,  328,  328,  328,  328,  328,  328,  328,  328,  328,
      328,  328,  328,  328,  328,  328,  328,  328,  328,  328,

      328,  328,  328,  328,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  423,  423,  423,  423,  423,  423,
      423,  423,  354,  354,  354,  354,  354,  354,  434,  434,
      434,  434,  434,  434,  434,  434,  434,  434,  435,  435,
      435,  435,  435,  435,  435,  435,  434,  434,  434,  434,
      434,  434,  492,  492,  492,  492,  492,  492,  492,  492,
      492,  492,  493,  493,  493,  493,  493,  493,  493,  493,
      492,  492,  492,  492,  492,  492,  538,  538,  538,  538,
      538,  538,  538,  538,  538,  538,  539,  539,  539,  539,
      539,  539,  539,  539,  538,  538,  538,  538,  538,  538,

      568,  568,  568,  568,  568,  568,  568,  568,  568,  568,
      569,  569,  569,  569,  569,  569,  569,  569,  568,  568,
      568,  568,  568,  568,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  626,  626,  626,  626,
      626,  626,  626,  626,  626,  626,  626,  626,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      628,  562,  561,  628,  630,  560,  559,  558,  630,  630,
      630,  630,  631,  557,  556,  631,  632,  555,  632,  632,
      632,  632,  632,  632,  632,  632,  632,  632,  633,  553,
      633,  633,  633,  634,  551,  634,  550,  634,  634,  634,

      634,  634,  634,  634,  634,  635,  549,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  636,  636,  637,
      546,  637,  637,  637,  637,  637,  637,  637,  637,  637,
      637,  638,  545,  638,  638,  638,  639,  544,  639,  639,
      639,  640,  640,  640,  640,  640,  641,  641,  641,  641,
      641,  642,  543,  542,  642,  643,  537,  532,  531,  529,
      528,  527,  526,  643,  643,  644,  523,  521,  644,  645,
      519,  517,  515,  514,  645,  645,  646,  509,  506,  505,
      504,  503,  502,  501,  646,  646,  647,  499,  497,  647,
      648,  648,  649,  490,  489,  488,  649,  649,  650,  486,

      483,  650,  651,  651,  652,  481,  480,  479,  477,  652,
      652,  653,  653,  654,  476,  475,  654,  655,  655,  656,
      474,  473,  656,  657,  657,  658,  472,  470,  658,  659,
      659,  469,  466,  464,  463,  462,  461,  460,  459,  458,
      457,  456,  455,  454,  453,  452,  451,  450,  449,  448,
      447,  444,  442,  441,  440,  439,  425,  424,  422,  420,
      419,  418,  417,  416,  415,  412,  411,  410,  409,  408,
      407,  406,  405,  404,  403,  402,  401,  400,  398,  397,
      394,  392,  391,  390,  389,  388,  387,  386,  380,  377,
      376,  375,  374,  373,  372,  371,  369,  368,  367,  366,

      365,  363,  362,  361,  360,  359,  345,  334,  333,  332,
      331,  330,  329,  327,  326,  325,  324,  323,  322,  321,
      320,  319,  318,  317,  313,  312,  310,  309,  308,  307,
      305,  304,  303,  302,  301,  298,  297,  296,  295,  294,
      293,  292,  291,  290,  289,  288,  287,  286,  285,  284,
      283,  281,  280,  279,  278,  276,  275,  274,  273,  272,
      271,  270,  268,  258,  257,  254,  242,  237,  235,  233,
      232,  229,  226,  223,  214,  213,  211,  210,  207,  205,
      204,  203,  201,  200,  199,  198,  197,  195,  193,  191,
      188,  186,  183,  182,  181,  180,  179,  178,  177,  176,

      172,  170,  168,  165,  164,  163,  161,  159,  157,  155,
      154,  152,  151,  129,  128,  127,  123,  122,  121,  119,
      118,  117,  116,  115,  114,  113,  108,  106,  103,   94,
       78,   76,   75,   71,   69,   66,   63,   62,   50,   49,
       48,   46,   45,   42,   37,   23,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,

      624,  624,  624,  624,  624,  624,  624,  624
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = yy_full_lp; /* restore orig. accepting pos. */ \
(yy_state_ptr) = yy_full_state; /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "mon_lex.l"
/* -*- C -*-
 *
 * mon_lex.l - Lexer for the VICE built-in monitor.
 *
 * Written by
 *  Daniel Sladic <sladic@eecg.toronto.edu>
 *  Andreas Boose <viceteam@t-online.de>
 *  Thomas Giesel <skoe@directbox.com>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */
#line 31 "mon_lex.l"

/* Lexer for x64 monitor */

#include "vice.h"

#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "lib.h"
#include "mon_command.h"
#include "montypes.h"
#include "mon_parse.h" /* FIXME ! */
#include "types.h"


#define YY_ALWAYS_INTERACTIVE 1
#define YY_NO_UNISTD_H

#undef min
#define min(a,b) ((a) < (b) ? (a) : (b))

int new_cmd = 1, quote = 0, opt_asm = 0, cur_len = 0, last_len = 0, dont_match_reg_a = 0;
int temp, push_back;
static int yywrap(void);
YY_BUFFER_STATE my_state;

#define YY_USER_ACTION { last_len = cur_len; cur_len += yyleng; }


#line 1185 "mon_lex.c"

#define INITIAL 0
#define FNAME 1
#define CMD 2
#define STR 3
#define ROL 4
#define ASM_MODE 5
#define COND_MODE 6
#define REG_ASGN 7
#define LABEL_ASGN 8
#define BNAME 9
#define CTYPE 10

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if ( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 69 "mon_lex.l"



   if (new_cmd) {
      if (!(asm_mode && opt_asm))
         last_len = cur_len = 0;

      if (asm_mode) {
         BEGIN (ASM_MODE);
         opt_asm = 0;
      } else
         BEGIN (CMD);
      new_cmd = 0;
   }


#line 1365 "mon_lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 625 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1447 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yy_looking_for_trail_begin )
					{
					if ( yy_act == yy_looking_for_trail_begin )
						{
						yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					yy_full_state = (yy_state_ptr);
					yy_full_lp = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */

case 1:
YY_RULE_SETUP
#line 86 "mon_lex.l"
{ BEGIN(ROL);           return CMD_COMMENT; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 87 "mon_lex.l"
{ BEGIN(INITIAL);       return CONVERT_OP; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 88 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_ENTER_DATA; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 89 "mon_lex.l"
{ BEGIN(ROL);           return CMD_DISK; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 90 "mon_lex.l"
{ opt_asm = 1; BEGIN(INITIAL); return CMD_ASSEMBLE; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 91 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_ADD_LABEL; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 92 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_ATTACH; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 93 "mon_lex.l"
{ BEGIN(BNAME);         return CMD_BANK; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 94 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_BLOAD; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 95 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_BLOCK_READ; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 96 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_BREAK; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 97 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_BSAVE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 98 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_BACKTRACE; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 99 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_BLOCK_WRITE; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 100 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_CARTFREEZE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 101 "mon_lex.l"
{ BEGIN(ROL);           return CMD_CHDIR; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 102 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_COMMAND; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 103 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_COMPARE; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 104 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_CONDITION; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 105 "mon_lex.l"
{ BEGIN(CTYPE);         return CMD_CPU; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 106 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_CPUHISTORY; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 107 "mon_lex.l"
{ BEGIN(ROL);           return CMD_DIR; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 108 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_DISASSEMBLE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 109 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_DELETE; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 110 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_DEL_LABEL; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 111 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_DEVICE; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 112 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_DETACH; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 113 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_CHECKPT_OFF; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 114 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_DUMP; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 115 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_CHECKPT_ON; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 116 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_EXIT; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 117 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_FILL; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 118 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_GOTO; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 119 "mon_lex.l"
{ BEGIN(ROL);           return CMD_HELP; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 120 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_HUNT; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 121 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_TEXT_DISPLAY; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 122 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_SCREENCODE_DISPLAY; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 123 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_IGNORE; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 124 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_IO; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 125 "mon_lex.l"
{ BEGIN(ROL);           return CMD_KEYBUF; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 126 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_LOAD; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 127 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_LOAD_LABELS; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 128 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_MEM_DISPLAY; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 129 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_CHAR_DISPLAY; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 130 "mon_lex.l"
{ BEGIN(FNAME);       return CMD_MEMMAPSAVE; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 131 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_MEMMAPSHOW; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 132 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_MEMMAPZAP; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 133 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_MOVE; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 134 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_SPRITE_DISPLAY; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 135 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_NEXT; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 136 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_PLAYBACK; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 137 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_PRINT; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 138 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_PWD; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 139 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_QUIT; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 140 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_RADIX; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 141 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_RECORD; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 142 "mon_lex.l"
{ BEGIN(REG_ASGN);      return CMD_REGISTERS; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 143 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_MON_RESET; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 144 "mon_lex.l"
{ BEGIN(INITIAL);    return CMD_RESOURCE_GET; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 145 "mon_lex.l"
{ BEGIN(INITIAL);    return CMD_RESOURCE_SET; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 146 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_RETURN; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 147 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_SAVE; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 148 "mon_lex.l"
{ BEGIN(FNAME);         return CMD_SAVE_LABELS; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 149 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_SCREEN; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 150 "mon_lex.l"
{ BEGIN(FNAME);        return CMD_SCREENSHOT; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 151 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_SHOW_LABELS; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 152 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_SIDEFX; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 153 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_STEP; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 154 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_MON_STOP; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 155 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_TAPECTRL; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 156 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_TRACE; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 157 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_UNTIL; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 158 "mon_lex.l"
{ BEGIN(FNAME);       return CMD_UNDUMP; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 159 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_WATCH; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 160 "mon_lex.l"
{ BEGIN(INITIAL);       return CMD_YYDEBUG; }
	YY_BREAK

/* this is not a real command, but could be a label name for a label assignment */
case 76:
YY_RULE_SETUP
#line 163 "mon_lex.l"
{ BEGIN(LABEL_ASGN); yylval.str = lib_stralloc(yytext); return CMD_LABEL_ASGN; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 165 "mon_lex.l"
{ new_cmd = 1; return CMD_SEP; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 167 "mon_lex.l"
{ yylval.i = e_ON; return TOGGLE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 168 "mon_lex.l"
{ yylval.i = e_OFF; return TOGGLE; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 169 "mon_lex.l"
{ yylval.i = e_TOGGLE; return TOGGLE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 171 "mon_lex.l"
{ yylval.i = e_load; return MEM_OP; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 172 "mon_lex.l"
{ yylval.i = e_store; return MEM_OP; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 174 "mon_lex.l"
{ BEGIN (COND_MODE); return IF; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 176 "mon_lex.l"
{ if (!quote) {
                     quote = 1;
                     BEGIN (STR);
                  }
                }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 181 "mon_lex.l"
{ if (quote) {
                     quote = 0;
                     BEGIN (INITIAL);
                  }
                }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 187 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return STRING; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 190 "mon_lex.l"
{ yylval.i = e_hexadecimal; return INPUT_SPEC; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 191 "mon_lex.l"
{ yylval.i = e_decimal; return INPUT_SPEC; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 192 "mon_lex.l"
{ yylval.i = e_binary; return INPUT_SPEC; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 193 "mon_lex.l"
{ yylval.i = e_octal; return INPUT_SPEC; }
	YY_BREAK
/* \.TA		{ yylval.i = e_text_ascii; return INPUT_SPEC; } */
/* \.TP		{ yylval.i = e_text_petscii; return INPUT_SPEC; } */
/* \.\>		{ yylval.i = e_6502_asm; return INPUT_SPEC; } */
/* \.S		{ yylval.i = e_sprite; return INPUT_SPEC; } */
/* \.C		{ yylval.i = e_character; return INPUT_SPEC; } */
case 91:
YY_RULE_SETUP
#line 200 "mon_lex.l"
{ yylval.i = e_decimal; return RADIX_TYPE; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 201 "mon_lex.l"
{ yylval.i = e_hexadecimal; return RADIX_TYPE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 202 "mon_lex.l"
{ yylval.i = e_binary; return RADIX_TYPE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 203 "mon_lex.l"
{ yylval.i = e_octal; return RADIX_TYPE; }
	YY_BREAK
/* C		{ yylval.i = e_character; return RADIX_TYPE; } */
/* S		{ yylval.i = e_sprite; return RADIX_TYPE; } */
/* TA		{ yylval.i = e_text_ascii; return RADIX_TYPE; } */
/* TP		{ yylval.i = e_text_petscii; return RADIX_TYPE; } */
case 95:
YY_RULE_SETUP
#line 209 "mon_lex.l"
{ return MEM_COMP; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 210 "mon_lex.l"
{ return MEM_DISK8; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 211 "mon_lex.l"
{ return MEM_DISK9; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 212 "mon_lex.l"
{ return MEM_DISK10; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 213 "mon_lex.l"
{ return MEM_DISK11; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 215 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return CPUTYPE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 217 "mon_lex.l"

	YY_BREAK
case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 218 "mon_lex.l"
{ dont_match_reg_a = 0;
                 new_cmd = 1;
                 opt_asm = 0;
                 quote = 0;
                 BEGIN(INITIAL);
                 return TRAIL;
               }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 226 "mon_lex.l"
{ yytext[yyleng-1] = '\0';
                yylval.str = lib_stralloc(yytext+1);
                BEGIN (INITIAL); return FILENAME; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 230 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return BANKNAME; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 232 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return R_O_L; }
	YY_BREAK

case 106:
YY_RULE_SETUP
#line 235 "mon_lex.l"
{ yylval.i = e_A; return MON_REGISTER; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 236 "mon_lex.l"
{ yylval.i = e_X; return MON_REGISTER; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 237 "mon_lex.l"
{ yylval.i = e_Y; return MON_REGISTER; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 238 "mon_lex.l"
{ yylval.i = e_PC; return MON_REGISTER; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 239 "mon_lex.l"
{ yylval.i = e_SP; return MON_REGISTER; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 240 "mon_lex.l"
{ yylval.i = e_FLAGS; return MON_REGISTER; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 241 "mon_lex.l"
{ yylval.i = e_R3; return MON_REGISTER; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 242 "mon_lex.l"
{ yylval.i = e_R4; return MON_REGISTER; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 243 "mon_lex.l"
{ yylval.i = e_R5; return MON_REGISTER; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 244 "mon_lex.l"
{ yylval.i = e_R6; return MON_REGISTER; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 245 "mon_lex.l"
{ yylval.i = e_R7; return MON_REGISTER; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 246 "mon_lex.l"
{ yylval.i = e_R8; return MON_REGISTER; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 247 "mon_lex.l"
{ yylval.i = e_R9; return MON_REGISTER; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 248 "mon_lex.l"
{ yylval.i = e_R10; return MON_REGISTER; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 249 "mon_lex.l"
{ yylval.i = e_R11; return MON_REGISTER; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 250 "mon_lex.l"
{ yylval.i = e_R12; return MON_REGISTER; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 251 "mon_lex.l"
{ yylval.i = e_R13; return MON_REGISTER; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 252 "mon_lex.l"
{ yylval.i = e_R14; return MON_REGISTER; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 253 "mon_lex.l"
{ yylval.i = e_R15; return MON_REGISTER; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 254 "mon_lex.l"
{ yylval.i = e_ACM; return MON_REGISTER; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 255 "mon_lex.l"
{ yylval.i = e_YXM; return MON_REGISTER; }
	YY_BREAK


case 127:
YY_RULE_SETUP
#line 259 "mon_lex.l"
{ yylval.i = e_EQU; return COMPARE_OP; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 260 "mon_lex.l"
{ yylval.i = e_NEQ; return COMPARE_OP; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 261 "mon_lex.l"
{ yylval.i = e_LTE; return COMPARE_OP; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 262 "mon_lex.l"
{ yylval.i = e_LT;  return COMPARE_OP; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 263 "mon_lex.l"
{ yylval.i = e_GT;  return COMPARE_OP; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 264 "mon_lex.l"
{ yylval.i = e_GTE; return COMPARE_OP; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 265 "mon_lex.l"
{ yylval.i = e_AND; return COMPARE_OP; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 266 "mon_lex.l"
{ yylval.i = e_OR;  return COMPARE_OP; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 268 "mon_lex.l"
{ yylval.i = e_A; return MON_REGISTER; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 269 "mon_lex.l"
{ yylval.i = e_X; return MON_REGISTER; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 270 "mon_lex.l"
{ yylval.i = e_Y; return MON_REGISTER; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 271 "mon_lex.l"
{ yylval.i = e_PC; return MON_REGISTER; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 272 "mon_lex.l"
{ yylval.i = e_SP; return MON_REGISTER; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 273 "mon_lex.l"
{ yylval.i = e_R3; return MON_REGISTER; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 274 "mon_lex.l"
{ yylval.i = e_R4; return MON_REGISTER; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 275 "mon_lex.l"
{ yylval.i = e_R5; return MON_REGISTER; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 276 "mon_lex.l"
{ yylval.i = e_R6; return MON_REGISTER; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 277 "mon_lex.l"
{ yylval.i = e_R7; return MON_REGISTER; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 278 "mon_lex.l"
{ yylval.i = e_R8; return MON_REGISTER; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 279 "mon_lex.l"
{ yylval.i = e_R9; return MON_REGISTER; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 280 "mon_lex.l"
{ yylval.i = e_R10; return MON_REGISTER; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 281 "mon_lex.l"
{ yylval.i = e_R11; return MON_REGISTER; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 282 "mon_lex.l"
{ yylval.i = e_R12; return MON_REGISTER; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 283 "mon_lex.l"
{ yylval.i = e_R13; return MON_REGISTER; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 284 "mon_lex.l"
{ yylval.i = e_R14; return MON_REGISTER; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 285 "mon_lex.l"
{ yylval.i = e_R15; return MON_REGISTER; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 286 "mon_lex.l"
{ yylval.i = e_ACM; return MON_REGISTER; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 287 "mon_lex.l"
{ yylval.i = e_YXM; return MON_REGISTER; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 289 "mon_lex.l"
{ return L_PAREN; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 290 "mon_lex.l"
{ return R_PAREN; }
	YY_BREAK

case 157:
YY_RULE_SETUP
#line 293 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 295 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 297 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 299 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 301 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 303 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 305 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 307 "mon_lex.l"
{
    yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 309 "mon_lex.l"
{ return REG_AF; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 310 "mon_lex.l"
{ return REG_BC; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 311 "mon_lex.l"
{ return REG_DE; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 312 "mon_lex.l"
{ return REG_HL; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 313 "mon_lex.l"
{ return REG_IX; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 314 "mon_lex.l"
{ return REG_IXH; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 315 "mon_lex.l"
{ return REG_IXL; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 316 "mon_lex.l"
{ return REG_IY; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 317 "mon_lex.l"
{ return REG_IYH; }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 318 "mon_lex.l"
{ return REG_IYL; }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 319 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return OPCODE; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 320 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return LABEL; }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 321 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return LABEL; }
	YY_BREAK
case 178:
/* rule 178 can match eol */
YY_RULE_SETUP
#line 323 "mon_lex.l"
{ if (!dont_match_reg_a) return REG_A;
                                        yylval.i = 0x0a; return H_NUMBER; }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 325 "mon_lex.l"
{ return REG_B; }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 326 "mon_lex.l"
{ return REG_C; }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 327 "mon_lex.l"
{ return REG_D; }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 328 "mon_lex.l"
{ return REG_E; }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 329 "mon_lex.l"
{ return REG_H; }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 330 "mon_lex.l"
{ return REG_L; }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 331 "mon_lex.l"
{ return REG_X; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 332 "mon_lex.l"
{ return REG_Y; }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 334 "mon_lex.l"
{ dont_match_reg_a = 1; return L_PAREN; }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 335 "mon_lex.l"
{ dont_match_reg_a = 0; return R_PAREN; }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 336 "mon_lex.l"
{ dont_match_reg_a = 1; return ARG_IMMEDIATE; }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 337 "mon_lex.l"
{ dont_match_reg_a = 0; return INST_SEP; }
	YY_BREAK

case 191:
YY_RULE_SETUP
#line 340 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return H_RANGE_GUESS; }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 341 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return B_NUMBER_GUESS; }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 342 "mon_lex.l"
{ yylval.i = strtol(yytext+1, NULL, 2); return B_NUMBER; }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 343 "mon_lex.l"
{ yylval.i = strtol(yytext+1, NULL, 8); return O_NUMBER; }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 344 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return O_NUMBER_GUESS; }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 345 "mon_lex.l"
{ yylval.i = strtol(yytext+1, NULL, 10); return D_NUMBER; }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 346 "mon_lex.l"
{ yylval.str = lib_stralloc(yytext); return D_NUMBER_GUESS; }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 347 "mon_lex.l"
{ yylval.i = 0x00; return MASK; }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 348 "mon_lex.l"
{ yylval.i = strtol(yytext+1, NULL, 16); return H_NUMBER; }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 349 "mon_lex.l"
{ yylval.i = strtol(yytext, NULL, 16); return H_NUMBER; }
	YY_BREAK

case 201:
YY_RULE_SETUP
#line 352 "mon_lex.l"
{ return EQUALS; }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 353 "mon_lex.l"
{ return COMMA; }
	YY_BREAK
/* After a label assignment there may be a ; comment to EOL */
case 203:
YY_RULE_SETUP
#line 356 "mon_lex.l"
{ return LABEL_ASGN_COMMENT; }
	YY_BREAK
case 204:
/* rule 204 can match eol */
YY_RULE_SETUP
#line 358 "mon_lex.l"
{ return yytext[0]; }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 360 "mon_lex.l"
ECHO;
	YY_BREAK
#line 2547 "mon_lex.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(FNAME):
			case YY_STATE_EOF(CMD):
			case YY_STATE_EOF(STR):
			case YY_STATE_EOF(ROL):
			case YY_STATE_EOF(ASM_MODE):
			case YY_STATE_EOF(COND_MODE):
			case YY_STATE_EOF(REG_ASGN):
			case YY_STATE_EOF(LABEL_ASGN):
			case YY_STATE_EOF(BNAME):
			case YY_STATE_EOF(CTYPE):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 625 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 625 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 624);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while (YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 360 "mon_lex.l"



void free_buffer(void)
{
   yy_delete_buffer(my_state);
}

void make_buffer(char *str)
{
    my_state = yy_scan_buffer(str,strlen(str) + 2);
    assert(my_state);
}

static int yywrap(void)
{
    return 1;
}


